==> gnucash_1.8.10.orig.tar.gz: gnucash-1.8.10/src/gnome-utils/gnc-dir.h <==
/**-*- c -*-*********************************************************\
 * gnc-dir.h -- directories for GnuCash                             *
 * Copyright (C) 2001 Gnumatic, Inc.                                *
 *                                                                  *
 * This program is free software; you can redistribute it and/or    *
 * modify it under the terms of the GNU General Public License as   *
 * published by the Free Software Foundation; either version 2 of   *
 * the License, or (at your option) any later version.              *
 *                                                                  *
 * This program is distributed in the hope that it will be useful,  *
 * but WITHOUT ANY WARRANTY; without even the implied warranty of   *
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the    *
 * GNU General Public License for more details.                     *
 *                                                                  *
 * You should have received a copy of the GNU General Public License*
 * along with this program; if not, contact:                        *
 *                                                                  *
 * Free Software Foundation           Voice:  +1-617-542-5942       *
 * 59 Temple Place - Suite 330        Fax:    +1-617-542-2652       *
 * Boston, MA  02111-1307,  USA       gnu@gnu.org                   *
\********************************************************************/

#ifndef GNC_DIR_H
#define GNC_DIR_H

#define GNC_ACCOUNTS_DIR "/usr/local/share/gnucash/accounts"
#define GNC_GLADE_DIR "/usr/local/share/gnucash/glade"
#define GNC_PIXMAP_DIR "/usr/local/share/pixmaps/gnucash"

#endif

==> gnucash_1.8.12.orig.tar.gz: gnucash-1.8.12/src/gnome-utils/gnc-dir.h <==
/**-*- c -*-*********************************************************\
 * gnc-dir.h -- directories for GnuCash                             *
 * Copyright (C) 2001 Gnumatic, Inc.                                *
 *                                                                  *
 * This program is free software; you can redistribute it and/or    *
 * modify it under the terms of the GNU General Public License as   *
 * published by the Free Software Foundation; either version 2 of   *
 * the License, or (at your option) any later version.              *
 *                                                                  *
 * This program is distributed in the hope that it will be useful,  *
 * but WITHOUT ANY WARRANTY; without even the implied warranty of   *
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the    *
 * GNU General Public License for more details.                     *
 *                                                                  *
 * You should have received a copy of the GNU General Public License*
 * along with this program; if not, contact:                        *
 *                                                                  *
 * Free Software Foundation           Voice:  +1-617-542-5942       *
 * 59 Temple Place - Suite 330        Fax:    +1-617-542-2652       *
 * Boston, MA  02111-1307,  USA       gnu@gnu.org                   *
\********************************************************************/

#ifndef GNC_DIR_H
#define GNC_DIR_H

#define GNC_ACCOUNTS_DIR "/usr/share/gnucash/accounts"
#define GNC_GLADE_DIR "/usr/share/gnucash/glade"
#define GNC_PIXMAP_DIR "/usr/share/pixmaps/gnucash"

#endif
